@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2013, OFFIS e.V.
+ *  Copyright (C) 2002-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -111,9 +111,9 @@ static OFCondition writeFile(STD_NAMESPACE ostream &out,
                 {
                     /* the dataset contains non-ASCII characters that really should not be there */
                     OFLOG_ERROR(dcm2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": SpecificCharacterSet (0008,0005) "
-                        << "element absent (on the main dataset level) but extended characters used in file: " << ifname);
+                        << "element absent (on the main data set level) but extended characters used in file: " << ifname);
                     OFLOG_DEBUG(dcm2xmlLogger, "use option --charset-assume to manually specify an appropriate character set");
-                    return EC_IllegalCall;
+                    return makeOFCondition(OFM_dcmdata, EC_CODE_CannotSelectCharacterSet, OF_error, "Missing Specific Character Set");;
                 } else {
                     OFString sopClass;
                     csetString = defaultCharset;
@@ -141,7 +141,7 @@ static OFCondition writeFile(STD_NAMESPACE ostream &out,
                     else {
                         OFLOG_FATAL(dcm2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": Character set '"
                             << defaultCharset << "' specified with option --charset-assume not supported");
-                        return EC_IllegalCall;
+                        return makeOFCondition(OFM_dcmdata, EC_CODE_CannotSelectCharacterSet, OF_error, "Cannot select character set");
                     }
                     /* check whether this file is a DICOMDIR */
                     if (dfile->getMetaInfo()->findAndGetOFString(DCM_MediaStorageSOPClassUID, sopClass).bad() ||
@@ -158,7 +158,7 @@ static OFCondition writeFile(STD_NAMESPACE ostream &out,
                 {
                     /* use "debug" instead of "warn" in order to avoid too much output in default mode */
                     OFLOG_DEBUG(dcm2xmlLogger, "ignoring character set '" << defaultCharset
-                        << "' specified with option --charset-assume since it is not needed for this dataset");
+                        << "' specified with option --charset-assume since it is not needed for this data set");
                 }
                 /* by default, we use UTF-8 encoding */
                 encString = "UTF-8";
@@ -267,7 +267,7 @@ int main(int argc, char *argv[])
         cmd.addOption("--charset-require",    "+Cr",    "require declaration of extended charset (def.)");
         cmd.addOption("--charset-assume",     "+Ca", 1, "[c]harset: string",
                                                         "assume charset c if no extended charset declared");
-        cmd.addOption("--charset-check-all",  "+Cc",    "check all data elements with string values\n(default: only PN, LO, LT, SH, ST and UT)");
+        cmd.addOption("--charset-check-all",  "+Cc",    "check all data elements with string values\n(default: only PN, LO, LT, SH, ST, UC and UT)");
 #ifdef WITH_LIBICONV
         cmd.addOption("--convert-to-utf8",    "+U8",    "convert all element values that are affected\nby Specific Character Set (0008,0005) to UTF-8");
 #endif
@@ -547,22 +547,34 @@ int main(int argc, char *argv[])
                     if (stream.good())
                     {
                         /* write content in XML format to file */
-                        if (writeFile(stream, ifname, &dfile, opt_readMode, opt_loadIntoMemory, opt_dtdFilename,
-                                      opt_defaultCharset, opt_writeFlags, opt_checkAllStrings).bad())
+                        status = writeFile(stream, ifname, &dfile, opt_readMode, opt_loadIntoMemory, opt_dtdFilename,
+                            opt_defaultCharset, opt_writeFlags, opt_checkAllStrings);
+                        if (status.bad())
+                        {
+                            OFLOG_ERROR(dcm2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << status.text() << ") writing file: "<< ofname);
                             result = 2;
+                        }
                     } else
                         result = 1;
                 } else {
                     /* write content in XML format to standard output */
-                    if (writeFile(COUT, ifname, &dfile, opt_readMode, opt_loadIntoMemory, opt_dtdFilename,
-                                  opt_defaultCharset, opt_writeFlags, opt_checkAllStrings).bad())
+                    status = writeFile(COUT, ifname, &dfile, opt_readMode, opt_loadIntoMemory, opt_dtdFilename,
+                        opt_defaultCharset, opt_writeFlags, opt_checkAllStrings);
+                    if (status.bad())
+                    {
+                        OFLOG_ERROR(dcm2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << status.text() << ") writing to standard output");
                         result = 3;
+                    }
                 }
             }
-        } else
+        } else {
             OFLOG_ERROR(dcm2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << status.text() << ") reading file: "<< ifname);
-    } else
+            result = 5;
+        }
+    } else {
         OFLOG_ERROR(dcm2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>");
+        result = 6;
+    }
 
     return result;
 }
