@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -461,17 +461,11 @@ int main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--enable-new-vr"))
       {
-        dcmEnableUnknownVRGeneration.set(OFTrue);
-        dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-        dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
-        dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
+        dcmEnableGenerationOfNewVRs();
       }
       if (cmd.findOption("--disable-new-vr"))
       {
-        dcmEnableUnknownVRGeneration.set(OFFalse);
-        dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-        dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
-        dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
+        dcmDisableGenerationOfNewVRs();
       }
       cmd.endOptionBlock();
 
