@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -47,6 +47,13 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 {
   public:
 
+    // be friend with "greater than" and "less than" operators that are defined
+    // outside of this class
+    friend OFBool operator< (const DcmItem& lhs, const DcmItem& rhs);
+    friend OFBool operator> (const DcmItem& lhs, const DcmItem& rhs);
+    friend OFBool operator<=(const DcmItem& lhs, const DcmItem& rhs);
+    friend OFBool operator>=(const DcmItem& lhs, const DcmItem& rhs);
+
     /** default constructor
      */
     DcmItem();
@@ -66,10 +73,31 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 
     /** assignment operator. Private creator cache is not copied
      *  as it is also the case for clone().
-     *  @param the item to be copied
+     *  @param obj the item to be copied
+     *  @return Reference to this object after assignment
      */
     DcmItem &operator=(const DcmItem &obj);
 
+    /** comparison operator that compares the normalized value of this object
+     *  with a given object of the same type. The tag of the element is also
+     *  considered as the first component that is compared, followed by the
+     *  object types (VR, i.e. DCMTK'S EVR) and the comparison of all value
+     *  components of the object, preferably in the order declared in the
+     *  object (if applicable). For item values that means that all elements
+     *  within the items are compared to each other in ascending tag order.
+     *  This may be an expensive operation.
+     *  @param  rhs the right hand side of the comparison
+     *  @return 0 if the object values are equal.
+     *          -1 if either the value of the  first component that does not match
+     *          is lower in this object than in rhs, or all compared components match
+     *          but this object has fewer components than rhs. Also returned if rhs
+     *          cannot be casted to this object type.
+     *          1 if either the value of the first component that does not match
+     *          is greater in this object than in rhs object, or all compared
+     *          components match but the this component is longer.
+     */
+    virtual int compare(const DcmItem& rhs) const;
+
     /** destructor
      */
     virtual ~DcmItem();
@@ -144,7 +172,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
      *  VR field and the value itself, for items and sequences it returns
      *  the length of the complete item or sequence including delimitation tags
      *  if applicable.
-     *  If length encodig is set to be explicit and the total item size is
+     *  If length encoding is set to be explicit and the total item size is
      *  larger than the available 32-bit length field, then undefined length
      *  is returned. If "dcmWriteOversizedSeqsAndItemsImplicit" is disabled,
      *  also the internal DcmObject errorFlag is set to EC_SeqOrItemContentOverflow
@@ -160,7 +188,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
     /** calculate the value length (without attribute tag, VR and length field)
      *  of this DICOM element when encoded with the given transfer syntax and
      *  the given encoding type for sequences.
-     *  If length encodig is set to be explicit and the item content is larger
+     *  If length encoding is set to be explicit and the item content is larger
      *  than the available 32-bit length field, then undefined length is
      *  returned. If "dcmWriteOversizedSeqsAndItemsUndefined" is disabled,
      *  also the internal DcmObject errorFlag is set to
@@ -257,7 +285,8 @@ class DCMTK_DCMDATA_EXPORT DcmItem
      *  character codes below 128 are considered to be ASCII codes and all others are
      *  considered to be non-ASCII.
      *  @param checkAllStrings if true, also check elements with string values not affected
-     *    by SpecificCharacterSet (0008,0005), default: only check PN, LO, LT, SH, ST, UT
+     *    by SpecificCharacterSet (0008,0005). By default, only check PN, LO, LT, SH, ST,
+     *    UC and UT.
      *  @return true if object contains non-ASCII characters, false otherwise
      */
     virtual OFBool containsExtendedCharacters(const OFBool checkAllStrings = OFFalse);
@@ -265,7 +294,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
     /** check if this object is affected by SpecificCharacterSet at any nesting level.
      *  In detail, it is checked whether this object contains any data elements that
      *  according to their VR are affected by the SpecificCharacterSet (0008,0005)
-     *  element. This is true for the following VRs: PN, LO, LT, SH, ST and UT
+     *  element. This is true for the following VRs: PN, LO, LT, SH, ST, UC and UT
      *  @return true if object is affected by SpecificCharacterSet, false otherwise
      */
     virtual OFBool isAffectedBySpecificCharacterSet() const;
@@ -565,7 +594,8 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                    DcmStack &resultStack);
 
     /** find element and get value as a reference to a C string. NB: The string is not copied!
-     *  Applicable to the following VRs: AE, AS, CS, DA, DS, DT, IS, LO, LT, PN, SH, ST, TM, UI, UT
+     *  Applicable to the following VRs: AE, AS, CS, DA, DS, DT, IS, LO, LT, PN, SH, ST, TM, UC, UI,
+     *  UR, UT
      *  Since the getString() routine is called internally the resulting string reference represents
      *  the (possibly multi-valued) value as stored in the dataset, i.e. no normalization is performed.
      *  The result variable 'value' is automatically set to NULL if an error occurs.
@@ -579,7 +609,8 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                  const OFBool searchIntoSub = OFFalse);
 
     /** find element and get value as a reference to a C string. NB: The string is not copied!
-     *  Applicable to the following VRs: AE, AS, CS, DA, DS, DT, IS, LO, LT, PN, SH, ST, TM, UI, UT
+     *  Applicable to the following VRs: AE, AS, CS, DA, DS, DT, IS, LO, LT, PN, SH, ST, TM, UC, UI,
+     *  UR, UT
      *  Since the getString() routine is called internally the resulting string reference represents
      *  the (possibly multi-valued) value as stored in the dataset, i.e. no normalization is performed.
      *  The result variable 'value' is automatically set to NULL and 'length' is set to 0 if an error
@@ -599,7 +630,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 
     /** find element and get value as a C++ string (only one component).
      *  Applicable to the following VRs: AE, AS, AT, CS, DA, DS, DT, FL, FD, IS, LO, LT, OB, OD, OF,
-     *  OW, PN, SH, SL, SS, ST, TM, UI, UL, US, UT
+     *  OL, OW, PN, SH, SL, SS, ST, TM, UC, UI, UL, UR, US, UT
      *  Since the getOFString() routine is called internally the resulting string is normalized, i.e.
      *  leading and/or trailing spaces are removed according to the associated value representation,
      *  or the element value is converted to a character string (for non-string VRs) - see documentation
@@ -620,7 +651,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 
     /** find element and get value as a C++ string (all components).
      *  Applicable to the following VRs: AE, AS, AT, CS, DA, DS, DT, FL, FD, IS, LO, LT, OB, OD, OF,
-     *  OW, PN, SH, SL, SS, ST, TM, UI, UL, US, UT
+     *  OL, OW, PN, SH, SL, SS, ST, TM, UC, UI, UL, UR, US, UT
      *  Since the getOFStringArray() routine is called internally the resulting string is normalized,
      *  i.e. leading and/or trailing spaces are removed according to the associated value representation
      *  or the element values are converted to character strings (for non-string VRs) - see documentation
@@ -720,7 +751,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                       const OFBool searchIntoSub = OFFalse);
 
     /** find element and get value as an unsigned 32-bit integer.
-     *  Applicable to the following VRs: UL
+     *  Applicable to the following VRs: OL, UL
      *  The result variable 'value' is automatically set to zero if an error occurs.
      *  @param tagKey DICOM tag specifying the attribute to be searched for
      *  @param value variable in which the element value is stored
@@ -734,7 +765,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                  const OFBool searchIntoSub = OFFalse);
 
     /** find element and get value as an array of unsigned 32-bit integers.
-     *  Applicable to the following VRs: UL
+     *  Applicable to the following VRs: OL, UL
      *  The result variable 'value' is automatically set to NULL if an error occurs.
      *  @param tagKey DICOM tag specifying the attribute to be searched for
      *  @param value variable in which the reference to the element value is stored
@@ -776,7 +807,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                       const OFBool searchIntoSub = OFFalse);
 
     /** find element and get value as a (signed) long integer.
-     *  Applicable to the following VRs: IS, SL, SS, UL, US
+     *  Applicable to the following VRs: IS, OL, SL, SS, UL, US
      *  The result variable 'value' is automatically set to zero if an error occurs.
      *  @param tagKey DICOM tag specifying the attribute to be searched for
      *  @param value variable in which the element value is stored
@@ -938,7 +969,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 
     /** create a new element, put specified value to it and insert the element into the dataset/item.
      *  Applicable to the following VRs: AE, AS, AT, CS, DA, DS, DT, FL, FD, IS, LO, LT, OB, OD, OF,
-     *  OW, PN, SH, SL, SS, ST, TM, UI, UL, US, UT
+     *  OL, OW, PN, SH, SL, SS, ST, TM, UC, UI, UL, UR, US, UT
      *  @param tag DICOM tag specifying the attribute to be created
      *  @param value string value to be set for the new element (might be empty or NULL)
      *  @param replaceOld flag indicating whether to replace an existing element or not
@@ -950,7 +981,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 
     /** create a new element, put specified value to it and insert the element into the dataset/item.
      *  Applicable to the following VRs: AE, AS, AT, CS, DA, DS, DT, FL, FD, IS, LO, LT, OB, OD, OF,
-     *  OW, PN, SH, SL, SS, ST, TM, UI, UL, US, UT
+     *  OL, OW, PN, SH, SL, SS, ST, TM, UC, UI, UL, UR, US, UT
      *  Please note that since the length of the string has to be specified explicitly, the string
      *  can contain more than one NULL byte.
      *  @param tag DICOM tag specifying the attribute to be created
@@ -965,7 +996,8 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                    const OFBool replaceOld = OFTrue);
 
     /** create a new element, put specified value to it and insert the element into the dataset/item.
-     *  Applicable to the following VRs: AE, AS, CS, DA, DS, DT, IS, LO, LT, PN, SH, ST, TM, UI, UT
+     *  Applicable to the following VRs: AE, AS, CS, DA, DS, DT, IS, LO, LT, PN, SH, ST, TM, UC, UI,
+     *  UR, UT
      *  @param tag DICOM tag specifying the attribute to be created
      *  @param value value to be set for the new element (might be empty)
      *  @param replaceOld flag indicating whether to replace an existing element or not
@@ -1043,7 +1075,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                         const OFBool replaceOld = OFTrue);
 
     /** create a new element, put specified value to it and insert the element into the dataset/item.
-     *  Applicable to the following VRs: UL
+     *  Applicable to the following VRs: OL, UL
      *  @param tag DICOM tag specifying the attribute to be created
      *  @param value value to be set for the new element
      *  @param pos index of the value to be set (0..vm). A value can be appended to
@@ -1056,6 +1088,19 @@ class DCMTK_DCMDATA_EXPORT DcmItem
                                    const unsigned long pos = 0,
                                    const OFBool replaceOld = OFTrue);
 
+    /** create a new element, put specified value to it and insert the element into the dataset/item.
+     *  Applicable to the following VRs: OL, UL
+     *  @param tag DICOM tag specifying the attribute to be created
+     *  @param value value to be set for the new element
+     *  @param count number of values (not bytes!) to be copied from 'value'
+     *  @param replaceOld flag indicating whether to replace an existing element or not
+     *  @return EC_Normal upon success, an error code otherwise.
+     */
+    OFCondition putAndInsertUint32Array(const DcmTag &tag,
+                                       const Uint32 *value,
+                                       const unsigned long count,
+                                       const OFBool replaceOld = OFTrue);
+
     /** create a new element, put specified value to it and insert the element into the dataset/item.
      *  Applicable to the following VRs: SL
      *  @param tag DICOM tag specifying the attribute to be created
@@ -1142,7 +1187,7 @@ class DCMTK_DCMDATA_EXPORT DcmItem
 
     /** create a new element (with no value) and insert it into the dataset/item.
      *  Applicable to the following VRs: AE, AS, AT, CS, DA, DS, DT, FL, FD, IS, LO, LT, OB, OD, OF,
-     *  OW, PN, SH, SL, SQ, SS, ST, TM, UI, UL, US, UT
+     *  OL, OW, PN, SH, SL, SQ, SS, ST, TM, UC, UI, UL, UR, US, UT
      *  @param tag DICOM tag specifying the attribute to be created
      *  @param replaceOld flag indicating whether to replace an existing element or not
      *  @return EC_Normal upon success, an error code otherwise.
@@ -1291,6 +1336,56 @@ class DCMTK_DCMDATA_EXPORT DcmItem
     DcmPrivateTagCache privateCreatorCache;
 };
 
+/** Checks whether left hand side item is smaller than right hand side
+ *  item. Uses DcmItem's compare() method in order to perform the
+ *  comparison. See DcmItem::compare() for details.
+ *  @param lhs left hand side of the comparison
+ *  @param rhs right hand side of the comparison
+ *  @return OFTrue if lhs is smaller than rhs, OFFalse otherwise
+ */
+inline OFBool operator< (const DcmItem& lhs, const DcmItem& rhs)
+{
+  return ( lhs.compare(rhs) < 0 );
+}
+
+/** Checks whether left hand side item is greater than right hand side
+ *  item. Uses DcmItem's compare() method in order to perform the
+ *  comparison. See DcmItem::compare() for details.
+ *  @param lhs left hand side of the comparison
+ *  @param rhs right hand side of the comparison
+ *  @return OFTrue if lhs is greater than rhs, OFFalse otherwise
+ */
+inline OFBool operator> (const DcmItem& lhs, const DcmItem& rhs)
+{
+  return rhs < lhs;
+}
+
+/** Checks whether left hand side item is smaller than or equal to right hand
+ *  side item. Uses DcmItem's compare() method in order to perform the
+ *  comparison. See DcmItem::compare() for details.
+ *  @param lhs left hand side of the comparison
+ *  @param rhs right hand side of the comparison
+ *  @return OFTrue if lhs is smaller than rhs or both are equal, OFFalse
+ *          otherwise
+ */
+inline OFBool operator<=(const DcmItem& lhs, const DcmItem& rhs)
+{
+  return !(lhs > rhs);
+}
+
+/** Checks whether left hand side element is greater than or equal to right hand
+ *  side element. Uses DcmElement's compare() method in order to perform the
+ *  comparison. See DcmElement::compare() for details.
+ *  @param lhs left hand side of the comparison
+ *  @param rhs right hand side of the comparison
+ *  @return OFTrue if lhs is greater than rhs or both are equal, OFFalse
+ *          otherwise
+ */
+inline OFBool operator>=(const DcmItem& lhs, const DcmItem& rhs)
+{
+  return !(lhs < rhs);
+}
+
 //
 // SUPPORT FUNCTIONS
 //
