@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2011-2014, OFFIS e.V.
+ *  Copyright (C) 2011-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -265,7 +265,7 @@ class DCMTK_DCMNET_EXPORT DcmStorageSCU
      *                       conformance.  If OFFalse, only empty values are rejected.
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition addDicomFile(const OFString &filename,
+    OFCondition addDicomFile(const OFFilename &filename,
                              const E_FileReadMode readMode = ERM_fileOnly,
                              const OFBool checkValues = OFTrue);
 
@@ -371,7 +371,7 @@ class DCMTK_DCMNET_EXPORT DcmStorageSCU
          *  @param  transferSyntaxUID  Transfer Syntax UID of the SOP instance to be
          *                             transferred
          */
-        TransferEntry(const OFString &filename,
+        TransferEntry(const OFFilename &filename,
                       const E_FileReadMode readMode,
                       const OFString &sopClassUID,
                       const OFString &sopInstanceUID,
@@ -398,7 +398,7 @@ class DCMTK_DCMNET_EXPORT DcmStorageSCU
         ~TransferEntry();
 
         /// filename of the SOP instance to be transferred (if no 'Dataset' given)
-        const OFString Filename;
+        const OFFilename Filename;
         /// read mode that should be used to read the given SOP instance from file
         const E_FileReadMode FileReadMode;
         /// dataset of the SOP instance to be transferred (if no 'Filename' given)
@@ -450,56 +450,10 @@ class DCMTK_DCMNET_EXPORT DcmStorageSCU
      *                       only empty values are rejected.
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition addDicomFilesFromDICOMDIR(const OFString &filename,
+    OFCondition addDicomFilesFromDICOMDIR(const OFFilename &filename,
                                           const E_FileReadMode readMode,
                                           const OFBool checkValues);
 
-    // --- static methods ---
-
-    /** get SOP Class UID, SOP Instance UID and Transfer Syntax UID from a DICOM file.  The
-     *  first two UID values are either copied from the meta-header (preferred) or from the
-     *  dataset.  The latter is either copied from the meta-header (preferred) or determined
-     *  automatically (if possible).
-     *  @param  filename           name of the DICOM file from which the SOP Class UID and SOP
-     *                             Instance UID values are retrieved
-     *  @param  sopClassUID        variable in which the value of the SOP Class UID is stored
-     *  @param  sopInstanceUID     variable in which the value of the SOP Instance UID is
-     *                             stored
-     *  @param  transferSyntaxUID  variable in which the value of the Transfer Syntax UID is
-     *                             stored
-     *  @param  readMode           read mode passed to the DcmFileFormat::loadFile() method.
-     *                             If ERM_fileOnly, only the file meta information header is
-     *                             loaded, i.e. the behavior is identical to using
-     *                             ERM_metaOnly.
-     *  @return status, EC_Normal if successful, an error code otherwise
-     */
-    static OFCondition getSOPInstanceFromFile(const OFString &filename,
-                                              OFString &sopClassUID,
-                                              OFString &sopInstanceUID,
-                                              OFString &transferSyntaxUID,
-                                              const E_FileReadMode readMode);
-
-    /** get SOP Class UID, SOP Instance UID and Transfer Syntax UID from a DICOM dataset.
-     *  The first two UID values are directly copied from the dataset.  The latter is either
-     *  taken from the parameter 'datasetXfer' or, if it is unknown, determined automatically
-     *  from the dataset (if possible).
-     *  @param  dataset            DICOM dataset from which the SOP Class UID and SOP Instance
-     *                             UID values are retrieved
-     *  @param  datasetXfer        transfer syntax of the dataset (if known, otherwise it is
-     *                             determined automatically)
-     *  @param  sopClassUID        variable in which the value of the SOP Class UID is stored
-     *  @param  sopInstanceUID     variable in which the value of the SOP Instance UID is
-     *                             stored
-     *  @param  transferSyntaxUID  variable in which the value of the Transfer Syntax UID is
-     *                             stored
-     *  @return status, EC_Normal if successful, an error code otherwise
-     */
-    static OFCondition getSOPInstanceFromDataset(DcmDataset *dataset,
-                                                 const E_TransferSyntax datasetXfer,
-                                                 OFString &sopClassUID,
-                                                 OFString &sopInstanceUID,
-                                                 OFString &transferSyntaxUID);
-
     /** check given SOP Class UID, SOP Instance UID and Transfer Syntax UID for validity and
      *  conformance to the DICOM standard.  For all UID values, the compliance with the
      *  requirements of the value representation "Unique Identifier" (UI) and value
@@ -508,6 +462,8 @@ class DCMTK_DCMNET_EXPORT DcmStorageSCU
      *  For the Transfer Syntax UID, it is checked whether it is known and generally
      *  supported.  Further checks will be performed when the list of presentation contexts is
      *  created for the association negotiation.
+     *  This method is called for each SOP instance that is added to the transfer list by one
+     *  of the following methods: addDicomFile(), addDataset(), addDicomFilesFromDICOMDIR()
      *  @param  sopClassUID        value of the SOP Class UID to be checked
      *  @param  sopInstanceUID     value of the SOP Instance UID to be checked
      *  @param  transferSyntaxUID  value of the Transfer Syntax UID to be checked
@@ -516,10 +472,10 @@ class DCMTK_DCMNET_EXPORT DcmStorageSCU
      *                             are rejected.
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    static OFCondition checkSOPInstance(const OFString &sopClassUID,
-                                        const OFString &sopInstanceUID,
-                                        const OFString &transferSyntaxUID,
-                                        const OFBool checkValues);
+    virtual OFCondition checkSOPInstance(const OFString &sopClassUID,
+                                         const OFString &sopInstanceUID,
+                                         const OFString &transferSyntaxUID,
+                                         const OFBool checkValues);
 
     /** This method is called each time a SOP instance is sent to a peer.  Since it is called
      *  after the SOP instance has been processed, the transfer entry passed to this method
