@@ -1,9 +1,9 @@
 /*
  *
- *  Copyright (C) 2014-2015, OFFIS e.V.
+ *  Copyright (C) 2014-2016, J. Riesmeier, Oldenburg, Germany
  *  All rights reserved.  See COPYRIGHT file for details.
  *
- *  This software and supporting documentation were developed by
+ *  This software and supporting documentation are maintained by
  *
  *    OFFIS e.V.
  *    R&D Division Health
@@ -26,11 +26,12 @@
 
 #include "dcmtk/ofstd/oftest.h"
 #include "dcmtk/dcmsr/dsrdoc.h"
+#include "dcmtk/dcmsr/dsrtpltn.h"
 #include "dcmtk/dcmsr/dsrnumtn.h"
 #include "dcmtk/dcmsr/dsrtextn.h"
 
 
-OFTEST(dcmsr_addContentItem)
+OFTEST(dcmsr_addContentItem_1)
 {
     /* first, create an SR document to get an empty SR tree */
     DSRDocument doc(DSRTypes::DT_ComprehensiveSR);
@@ -61,6 +62,16 @@ OFTEST(dcmsr_addContentItem)
 }
 
 
+OFTEST(dcmsr_addContentItem_2)
+{
+    /* first, create an empty document subtree */
+    DSRDocumentSubTree tree;
+    /* then, try to add some invalid content items */
+    OFCHECK(tree.addContentItem(DSRTypes::createDocumentTreeNode(DSRTypes::RT_hasProperties, DSRTypes::VT_byReference), DSRTypes::AM_afterCurrent, OFTrue /*deleteIfFail*/).bad());
+    OFCHECK(tree.addContentItem(new DSRIncludedTemplateTreeNode(DSRSharedSubTemplate(NULL), DSRTypes::RT_contains), DSRTypes::AM_afterCurrent, OFTrue /*deleteIfFail*/).bad());
+}
+
+
 OFTEST(dcmsr_copyContentItem)
 {
     /* first, create a new SR document */
@@ -112,6 +123,25 @@ OFTEST(dcmsr_gotoNamedNode)
 }
 
 
+OFTEST(dcmsr_gotoAnnotatedNode)
+{
+    /* first, create a new SR document */
+    DSRDocument doc(DSRTypes::DT_ComprehensiveSR);
+    DSRDocumentTree &tree = doc.getTree();
+    /* then add some content items (and annotate them) */
+    OFCHECK(tree.addContentItem(DSRTypes::RT_isRoot, DSRTypes::VT_Container, DSRCodedEntryValue("121111", "DCM", "Summary")).good());
+    OFCHECK(tree.getCurrentContentItem().setAnnotationText("Root Node").good());
+    OFCHECK(tree.addChildContentItem(DSRTypes::RT_contains, DSRTypes::VT_Num, DSRCodedEntryValue("121206", "DCM", "Distance")).good());
+    OFCHECK(tree.getCurrentContentItem().setAnnotationText("Numeric Node").good());
+    const size_t nodeID = tree.getNodeID();
+    OFCHECK(tree.addContentItem(DSRTypes::RT_contains, DSRTypes::VT_Text, DSRCodedEntryValue("1234", "99_PRV", "NOS")).good());
+    OFCHECK(tree.getCurrentContentItem().setAnnotationText("Text Node").good());
+    /* and check the "search by name" function */
+    OFCHECK_EQUAL(tree.gotoAnnotatedNode("Numeric Node"), nodeID);
+    OFCHECK_EQUAL(tree.gotoAnnotatedNode("Text Node"), nodeID + 1);
+}
+
+
 OFTEST(dcmsr_createDocSubTree)
 {
     /* first, create an empty document subtree */
