@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2014, OFFIS e.V.
+ *  Copyright (C) 2000-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -30,7 +30,9 @@
 #include "dcmtk/ofstd/oftypes.h"    /* for OFBool */
 #include "dcmtk/ofstd/oftraits.h"   /* for OFenable_if, ... */
 #include "dcmtk/ofstd/ofcond.h"     /* for OFCondition */
+#include "dcmtk/ofstd/oflimits.h"   /* for OFnumeric_limits<T>::max() */
 
+#define INCLUDE_CASSERT
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSTRING
@@ -629,7 +631,7 @@ class DCMTK_OFSTD_EXPORT OFStandard
 
     /** convert character string to an octal format stream.
      *  All non-ASCII and control characters (code < #32 and >= #127) are converted to their
-     *  octal representation, i.e. to '\ooo' where 'ooo' are the three octal digits of the
+     *  octal representation, i.e. to '\\ooo' where 'ooo' are the three octal digits of the
      *  character.  All other characters are output as is.  See section 6.1.2.3 in DICOM PS 3.5.
      ** @param out stream used for the output
      *  @param sourceString source string to be converted.  May contain one or more NULL bytes.
@@ -643,7 +645,7 @@ class DCMTK_OFSTD_EXPORT OFStandard
 
     /** convert character string to an octal format string.
      *  All non-ASCII and control characters (code < #32 and >= #127) are converted to their
-     *  octal representation, i.e. to '\ooo' where 'ooo' are the three octal digits of the
+     *  octal representation, i.e. to '\\ooo' where 'ooo' are the three octal digits of the
      *  character.  All other characters are output as is.  See section 6.1.2.3 in DICOM PS 3.5.
      ** @param sourceString source string to be converted.  May contain one or more NULL bytes.
      *  @param octalString reference to character string where the result should be stored
@@ -707,59 +709,6 @@ class DCMTK_OFSTD_EXPORT OFStandard
     static size_t decodeBase64(const OFString &data,
                                unsigned char *&result);
 
-
-#ifndef DOXYGEN
-    static OFBool (isnan) (float f);
-    static OFBool (isnan) (double d);
-    template<typename Integer>
-    static inline OFTypename OFenable_if<OFis_integral<Integer>::value,OFBool>::type
-    (isnan) ( const Integer i ) { return (isnan) ( OFstatic_cast( double, i ) ); }
-
-    static OFBool (isinf) (float f);
-    static OFBool (isinf) (double d);
-    template<typename Integer>
-    static inline OFTypename OFenable_if<OFis_integral<Integer>::value,OFBool>::type
-    (isinf) ( const Integer i ) { return (isinf) ( OFstatic_cast( double, i ) ); }
-#else
-    /** Determines if the given floating point number is a not-a-number (NaN) value.
-     *  @param f the floating point value to inspect.
-     *  @return OFTrue if f is a NaN, OFFalse otherwise.
-     */
-    static OFBool isnan( float f );
-
-    /** Determines if the given floating point number is a not-a-number (NaN) value.
-     *  @param d the floating point value to inspect.
-     *  @return OFTrue if d is a NaN, OFFalse otherwise.
-     */
-    static OFBool isnan( double d );
-
-    /** Casts the argument to double and calls OFStandard::isnan(double) on the result.
-     *  @param i an integer, i.e. <kbd>OFis_integral<Integer>::value</kbd> equals <kbd>OFTrue</kbd>.
-     *  @return OFStandard::isnan(OFstatic_cast(double,i)).
-     */
-    template<typename Integer>
-    static OFBool isnan( Integer i );
-
-    /** Determines if the given floating point number is a positive or negative infinity.
-     *  @param f the floating point value to inspect.
-     *  @return OFTrue if f is infinite, OFFalse otherwise.
-     */
-    static OFBool isinf( float f );
-
-    /** Determines if the given floating point number is a positive or negative infinity.
-     *  @param d the floating point value to inspect.
-     *  @return OFTrue if d is infinite, OFFalse otherwise.
-     */
-    static OFBool isinf( double d );
-
-    /** Casts the argument to double and calls OFStandard::isinf(double) on the result.
-     *  @param i an integer, i.e. <kbd>OFis_integral<Integer>::value</kbd> equals <kbd>OFTrue</kbd>.
-     *  @return OFStandard::isinf(OFstatic_cast(double,i)).
-     */
-    template<typename Integer>
-    static OFBool isinf( Integer i );
-#endif
-
     /** converts a floating-point number from an ASCII
      *  decimal representation to internal double-precision format.
      *  Unlike the atof() function defined in Posix, this implementation
@@ -879,7 +828,7 @@ class DCMTK_OFSTD_EXPORT OFStandard
      */
     static long getProcessID();
 
-     /** check whether the addition of two 32-bit integers yields in an overflow
+    /** check whether the addition of two 32-bit integers yields in an overflow
      *  @param summand1 first integer value to be added
      *  @param summand2 second integer value to be added
      *  @return OFTrue if an overflow occurred during the addition, OFFalse otherwise
@@ -890,6 +839,51 @@ class DCMTK_OFSTD_EXPORT OFStandard
       return (0xffffffff - summand1 < summand2);
     }
 
+    /** check whether subtraction is safe (i.e.\ no underflow occurs) and if so,
+     *  perform it (i.e.\ compute minuend-subtrahend=difference). Only works for
+     *  unsigned types.
+     *  @param minuend number to subtract from
+     *  @param subtrahend number to subtract from minuend
+     *  @param difference difference, if subtraction is safe, otherwise the
+     *    parameter value is not touched by the function
+     *  @return OFTrue if subtraction is safe and could be performed, OFFalse
+     *   otherwise
+     */
+    template <typename T>
+    static OFBool
+    safeSubtract(T minuend, T subtrahend, T& difference)
+    {
+      assert(!OFnumeric_limits<T>::is_signed);
+      if (minuend < subtrahend) {
+        return OFFalse;
+      } else {
+        difference = minuend - subtrahend;
+        return OFTrue;
+      }
+    }
+
+    /** check whether addition is safe (i.e.\ no overflow occurs) and if so,
+     *  perform it (i.e.\ compute a+b=sum). Only works for unsigned types.
+     *  @param a first number to add
+     *  @param b second number to add
+     *  @param sum resulting sum of both numbers, if addition is safe, otherwise
+     *    parameter value is not touched by the function
+     *  @return OFTrue if addition is safe and could be performed, OFFalse
+     *    otherwise
+     */
+    template <typename T>
+    static OFBool
+    safeAdd(T a, T b, T& sum)
+    {
+      assert(!OFnumeric_limits<T>::is_signed);
+      if (OFnumeric_limits<T>::max() - a < b) {
+        return OFFalse;
+      } else {
+        sum = a + b;
+        return OFTrue;
+      }
+    }
+
     /** Thread-safe version of gethostbyname.
      *  @param name the host name.
      *  @return a OFStandard::OFHostent object.
@@ -918,7 +912,7 @@ class DCMTK_OFSTD_EXPORT OFStandard
 
     /** On Posix-like platform, this method executes setuid(getuid()),
      *  which causes the application to revert from root privileges to
-     *  thos of the calling user when the program is installed as
+     *  those of the calling user when the program is installed as
      *  setuid root. DCMTK command line tools that open a socket for
      *  incoming DICOM network connections will call this method immediately
      *  after opening the socket. Since DICOM by default operates on
@@ -936,6 +930,16 @@ class DCMTK_OFSTD_EXPORT OFStandard
      */
     static OFCondition dropPrivileges();
 
+    /** Retrieve the name of the user that started the current process.
+     *  @return the user name as an OFString value.
+     */
+    static OFString getUserName();
+
+    /** Retrieve the local domain name, e. g. 'localhost'.
+     *  @return the host name as an OFString value.
+     */
+    static OFString getHostName();
+
  private:
 
     /** private implementation of strlcpy. Called when strlcpy
