@@ -97,6 +97,7 @@
 #include "dcmtk/ofstd/offile.h"
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/oftuple.h"
+#include "dcmtk/ofstd/ofmath.h"
 
 #define INCLUDE_CMATH
 #define INCLUDE_CFLOAT
@@ -172,64 +173,6 @@ const unsigned int OFStandard::ftoa_alternate = 0x08;
 const unsigned int OFStandard::ftoa_leftadj   = 0x10;
 const unsigned int OFStandard::ftoa_zeropad   = 0x20;
 
-
-/* Some MacOS X versions define isinf() and isnan() in <math.h> but not in <cmath> */
-#if defined(__APPLE__) && defined(__MACH__) && !defined (__INTEL_COMPILER)
-#undef HAVE_PROTOTYPE_ISINF
-#undef HAVE_PROTOTYPE_ISNAN
-#endif
-
-
-// some systems don't properly define isnan()
-#ifdef HAVE_ISNAN
-#ifndef HAVE_PROTOTYPE_ISNAN
-extern "C"
-{
-  int isnan(double value);
-}
-#endif
-#endif
-
-
-// some systems don't properly define finite()
-#ifdef HAVE_FINITE
-#ifndef HAVE_PROTOTYPE_FINITE
-extern "C"
-{
-  int finite(double value);
-}
-#endif
-#endif
-
-#if !defined(HAVE_ISINF) && defined(HAVE_PROTOTYPE_ISINF)
-#   define HAVE_ISINF 1
-#endif
-
-// some systems don't properly define isinf()
-#ifdef HAVE_ISINF
-#ifndef HAVE_PROTOTYPE_ISINF
-extern "C"
-{
-  int isinf(double value);
-}
-#endif
-
-#else /* HAVE_ISINF */
-
-static int my_isinf(double x)
-{
-#if defined(DCMTK_USE_CXX11_STL) || ( defined(__MINGW32__) && __cplusplus >= 201103L )
-  return STD_NAMESPACE isinf(x);
-#elif defined(HAVE_WINDOWS_H)
-  return (! _finite(x)) && (! _isnan(x));
-#else
-  // Solaris 2.5.1 has finite() and isnan() but not isinf().
-  return (! finite(x)) && (! isnan(x));
-#endif
-}
-#endif /* HAVE_ISINF */
-
-
 // --- string functions ---
 
 #ifndef HAVE_STRLCPY
@@ -782,8 +725,8 @@ OFFilename &OFStandard::combineDirAndFilename(OFFilename &result,
             OFFilename tmpDirName(result);
             result.set(tmpDirName.getCharPointer(), OFTrue /*convert*/);
         }
-        /* check file name */
-        if ((strLength > 0) && (strValue[0] != L'.'))
+        /* check file name (ignore empty string and ".") */
+        if ((strLength > 1) || ((strLength == 1) && (strValue[0] != L'.')))
         {
             if (result.isEmpty())
                 result.set(strValue, OFTrue /*convert*/);
@@ -835,8 +778,8 @@ OFFilename &OFStandard::combineDirAndFilename(OFFilename &result,
         /* we only get here, if we don't have an absolute directory in "fileName" */
         /* now normalize the directory name */
         normalizeDirName(result, dirName, allowEmptyDirName);
-        /* check file name */
-        if ((strLength > 0) && (strValue[0] != '.'))
+        /* check file name (ignore empty string and ".") */
+        if ((strLength > 1) || ((strLength == 1) && (strValue[0] != '.')))
         {
             if (result.isEmpty())
                 result.set(strValue);
@@ -1142,7 +1085,7 @@ size_t OFStandard::searchDirectoryRecursively(const OFFilename &directory,
         while ((entry = readdir(dirPtr)) != NULL)
 #endif
         {
-            /* filter out current and parent directory */
+            /* filter out current (".") and parent directory ("..") */
             if ((strcmp(entry->d_name, ".") != 0) && (strcmp(entry->d_name, "..") != 0))
             {
                 /* avoid leading "." */
@@ -1992,42 +1935,6 @@ double OFStandard::atof(const char *s, OFBool *success)
 
 #endif /* DISABLE_OFSTD_ATOF */
 
-OFBool OFStandard::isnan( float f )
-{
-#ifdef HAVE_WINDOWS_H
-  return _isnan(f) != 0;
-#else
-  return ::isnan(f);
-#endif
-}
-
-OFBool OFStandard::isnan( double d )
-{
-#ifdef HAVE_WINDOWS_H
-  return _isnan(d) != 0;
-#else
-  return ::isnan(d);
-#endif
-}
-
-OFBool OFStandard::isinf( float f )
-{
-#ifdef HAVE_ISINF
-  return ::isinf( f );
-#else
-  return my_isinf( f ) != 0;
-#endif
-}
-
-OFBool OFStandard::isinf( double d )
-{
-#ifdef HAVE_ISINF
-  return ::isinf( d );
-#else
-  return my_isinf( d ) != 0;
-#endif
-}
-
 /* 11-bit exponent (VAX G floating point) is 308 decimal digits */
 #define FTOA_MAXEXP          308
 /* 128 bit fraction takes up 39 decimal digits; max reasonable precision */
@@ -2067,14 +1974,14 @@ void OFStandard::ftoa(
   unsigned char fmtch = 'G';
 
   // check if val is NAN
-  if (isnan(val))
+  if (OFMath::isnan(val))
   {
     OFStandard::strlcpy(dst, "nan", siz);
     return;
   }
 
   // check if val is infinity
-  if (isinf(val))
+  if (OFMath::isinf(val))
   {
     if (val < 0)
         OFStandard::strlcpy(dst, "-inf", siz);
@@ -2492,24 +2399,14 @@ void OFStandard::ftoa(
   if (!dst || !siz) return;
 
   // check if val is NAN
-#if defined(DCMTK_USE_CXX11_STL) || ( defined(__MINGW32__) && __cplusplus >= 201103L )
-  if (STD_NAMESPACE isnan(val))
-#elif defined(HAVE_WINDOWS_H)
-  if (_isnan(val))
-#else
-  if (isnan(val))
-#endif
+  if (OFMath::isnan(val))
   {
     OFStandard::strlcpy(dst, "nan", siz);
     return;
   }
 
   // check if val is infinity
-#ifdef HAVE_ISINF
-  if (isinf(val))
-#else
-  if (my_isinf(val))
-#endif
+  if (OFMath::isinf(val))
   {
     if (val < 0)
         OFStandard::strlcpy(dst, "-inf", siz);
